Index: branches/supervisor/src/main/java/omq/client/proxy/MultiProxymq.java
===================================================================
--- branches/supervisor/src/main/java/omq/client/proxy/MultiProxymq.java	(revision 104)
+++ branches/supervisor/src/main/java/omq/client/proxy/MultiProxymq.java	(revision 105)
@@ -25,5 +25,5 @@
 	private static final String multi = "multi#";
 
-	private String uid;
+	private String reference;
 	private Broker broker;
 	private Serializer serializer;
@@ -33,11 +33,11 @@
 	private transient String serializerType;
 
-	public MultiProxymq(String uid, Class<?> clazz, Broker broker) throws Exception {
-		this.uid = uid;
+	public MultiProxymq(String reference, Class<?> clazz, Broker broker) throws Exception {
+		this.reference = reference;
 		this.broker = broker;
 		serializer = broker.getSerializer();
 
 		Properties env = broker.getEnvironment();
-		exchange = multi + uid;
+		exchange = multi + reference;
 		serializerType = env.getProperty(ParameterQueue.PROXY_SERIALIZER, Serializer.JAVA);
 	}
@@ -52,10 +52,10 @@
 
 		// Add the correlation ID and create a replyTo property
-		BasicProperties props = new BasicProperties.Builder().appId(uid).correlationId(corrId).type(serializerType).build();
+		BasicProperties props = new BasicProperties.Builder().appId(reference).correlationId(corrId).type(serializerType).build();
 
 		byte[] bytesRequest = serializer.serialize(serializerType, request);
 		broker.publishMessge(exchange, routingkey, props, bytesRequest);
 
-		logger.debug("Proxymq: " + uid + " invokes " + methodName + ", corrID" + corrId + ", exchange: " + exchange + ", replyQueue: " + replyQueueName
+		logger.debug("Proxymq: " + reference + " invokes " + methodName + ", corrID" + corrId + ", exchange: " + exchange + ", replyQueue: " + replyQueueName
 				+ ", serializerType: " + serializerType + ", multi call: " + request.isMulti() + ", async call: " + request.isAsync());
 
Index: branches/supervisor/src/main/java/omq/client/proxy/Proxymq.java
===================================================================
--- branches/supervisor/src/main/java/omq/client/proxy/Proxymq.java	(revision 104)
+++ branches/supervisor/src/main/java/omq/client/proxy/Proxymq.java	(revision 105)
@@ -46,5 +46,5 @@
 	private static final String multi = "multi#";
 
-	private String uid;
+	private String reference;
 	private transient String exchange;
 	private transient String multiExchange;
@@ -72,9 +72,9 @@
 	 * Proxymq Constructor.
 	 * 
 	 * This constructor uses an uid to know which object will call. It also uses
 	 * Properties to set where to send the messages
 	 * 
 	 * @param uid
 	 *            The uid represents the unique identifier of a remote object
 	 * @param clazz
 	 *            It represents the real class of the remote object. With this
@@ -85,6 +85,6 @@
 	 * @throws Exception
 	 */
-	public Proxymq(String uid, Class<?> clazz, Broker broker) throws Exception {
-		this.uid = uid;
+	public Proxymq(String reference, Class<?> clazz, Broker broker) throws Exception {
+		this.reference = reference;
 		this.broker = broker;
 		rListener = broker.getResponseListener();
@@ -95,5 +95,5 @@
 		env = broker.getEnvironment();
 		exchange = env.getProperty(ParameterQueue.RPC_EXCHANGE, "");
-		multiExchange = multi + uid;
+		multiExchange = multi + reference;
 		replyQueueName = env.getProperty(ParameterQueue.RPC_REPLY_QUEUE);
 
@@ -165,9 +165,9 @@
 		} else {
 			exchange = this.exchange;
-			routingkey = uid;
+			routingkey = reference;
 		}
 
 		// Add the correlation ID and create a replyTo property
-		BasicProperties props = new BasicProperties.Builder().appId(uid).correlationId(corrId).replyTo(replyQueueName).type(serializerType)
+		BasicProperties props = new BasicProperties.Builder().appId(reference).correlationId(corrId).replyTo(replyQueueName).type(serializerType)
 				.deliveryMode(deliveryMode).build();
 
@@ -175,5 +175,5 @@
 		byte[] bytesRequest = serializer.serialize(serializerType, request);
 		broker.publishMessge(exchange, routingkey, props, bytesRequest);
-		logger.debug("Proxymq: " + uid + " invokes '" + request.getMethod() + "' , corrID: " + corrId + ", exchange: " + exchange + ", replyQueue: "
+		logger.debug("Proxymq: " + reference + " invokes '" + request.getMethod() + "' , corrID: " + corrId + ", exchange: " + exchange + ", replyQueue: "
 				+ replyQueueName + ", serializerType: " + serializerType + ", multi call: " + request.isMulti() + ", async call: " + request.isAsync()
 				+ ", delivery mode: " + deliveryMode);
@@ -359,5 +359,5 @@
 	@Override
 	public String getRef() {
-		return uid;
+		return reference;
 	}
 
@@ -72,9 +72,9 @@
 	 * Proxymq Constructor.
 	 * 
-	 * This constructor uses an uid to know which object will call. It also uses
+	 * This constructor uses an reference to know which object will call. It also uses
 	 * Properties to set where to send the messages
 	 * 
@@ -72,9 +72,9 @@
 	 * Properties to set where to send the messages
 	 * 
-	 * @param uid
-	 *            The uid represents the unique identifier of a remote object
+	 * @param reference
+	 *            The reference represents the unique identifier of a remote object
 	 * @param clazz
 	 *            It represents the real class of the remote object. With this
